.. image:: https://travis-ci.org/nickp60/pyutilsnrw.svg?branch=master
    :target: https://travis-ci.org/nickp60/pyutilsnrw

Nick's Python Utils
=======================

I am finding myself needing to reuse code snippets, so this package is an atempt at making things more portable
----
Currently, this is all assuming python3.5
----

I've got nothing else to put here, so I'll just list some Python gripes.

 * Pandas data frames are the worst. Why are there different syntaxes for getting rows versus columns?
 * Why cant funtions be bounded by braces? Whitespace doesn't have to be this important.
 * Python versioning. In R, we don't look back. We dont mess around with that pillar of salt stuff. If someone is doing work on Wooden Christmas Tree and they get an error, its no different from getting your July 4th decorations tangled in your christmas lights -- #shouldhavetakencareofthatagesago.  Why should I have to consider no less than  5 releases of python? Forget 2.7. Move on. Port the legacy code base; we are just delaying the inevidable. #thelongnow
 * Needing environment management
 *
